From 6c298e964f7352d82b13d5f60d8e5cc638176dcd Mon Sep 17 00:00:00 2001
From: Alexandre Detiste
Date: Sun, 14 Feb 2016 10:27:44 +0100
Subject: JANITORIAL: Typos detected with lintian & grep

---
 engines/scumm/actor.cpp                   | 2 +-
 engines/scumm/imuse_digi/dimuse_track.cpp | 4 ++--
 engines/scumm/players/player_v4a.cpp      | 4 ++--
 engines/scumm/scumm_v4.h                  | 2 +-
 engines/scumm/sound.cpp                   | 2 +-
 5 files changed, 7 insertions(+), 7 deletions(-)

(limited to 'engines/scumm')

diff --git a/engines/scumm/actor.cpp b/engines/scumm/actor.cpp
index 0d7ea39ec2..3a69b5f03c 100644
--- a/engines/scumm/actor.cpp
+++ b/engines/scumm/actor.cpp
@@ -861,7 +861,7 @@ L2C36:;
 			stopActorMoving();
 			return;
 		}
-		// 2C98: Yes, an exact copy of what just occured.. the original does this, so im doing it...
+		// 2C98: Yes, an exact copy of what just occurred.. the original does this, so im doing it...
 		//       Just to keep me sane when going over it :)
 		if (A == 0xFF) {
 			setActorFromTmp();
diff --git a/engines/scumm/players/player_v4a.cpp b/engines/scumm/players/player_v4a.cpp
index bd8ce3f7ad..58f53a6d7f 100644
--- a/engines/scumm/players/player_v4a.cpp
+++ b/engines/scumm/players/player_v4a.cpp
@@ -174,7 +174,7 @@ int Player_V4A::getMusicTimer() {
 		return 2000;
 	if (_musicId) {
 		// The titlesong (and a few others) is running with ~70 ticks per second and the scale seems to be based on that.
-		// The Game itself doesnt get the timing from the Tfmx Player however, so we just use the elapsed time
+		// The Game itself doesn't get the timing from the Tfmx Player however, so we just use the elapsed time
 		// 357 ~ 1000 * 25 * (1 / 70)
 		return _mixer->getSoundElapsedTime(_musicHandle) / 357;
 	}
@@ -183,7 +183,7 @@ int Player_V4A::getMusicTimer() {
 
 int Player_V4A::getSoundStatus(int nr) const {
 	// For music the game queues a variable the Tfmx Player sets through a special command.
-	// For sfx there seems to be no way to queue them, and the game doesnt try to.
+	// For sfx there seems to be no way to queue them, and the game doesn't try to.
 	return (nr == _musicId) ? _signal : 0;
 }
 
diff --git a/engines/scumm/scumm_v4.h b/engines/scumm/scumm_v4.h
index 28f619ceaa..a008023ff9 100644
--- a/engines/scumm/scumm_v4.h
+++ b/engines/scumm/scumm_v4.h
@@ -35,7 +35,7 @@ class ScummEngine_v4 : public ScummEngine_v5 {
 public:
 
 	/**
-	 * Prepared savegame used by the orginal save/load dialog.
+	 * Prepared savegame used by the original save/load dialog.
 	 * Must be valid as long as the savescreen is active. As we are not
 	 * notified when the savescreen is closed, memory is only freed on a game
 	 * reset, at the destruction of the engine or when the original save/load
diff --git a/engines/scumm/sound.cpp b/engines/scumm/sound.cpp
index 84d2b37f96..4d70ee8482 100644
--- a/engines/scumm/sound.cpp
+++ b/engines/scumm/sound.cpp
@@ -240,7 +240,7 @@ void Sound::playSound(int soundID) {
 		// mentioned in the bug report above; in case it is, I put a check here.
 		assert(soundID == 39);
 
-		// The samplerate is copied from the sound resouce 39 of the PC CD/VGA
+		// The samplerate is copied from the sound resource 39 of the PC CD/VGA
 		// version of Monkey Island.
 
 		// Read info from the header
diff --git a/engines/scumm/imuse_digi/dimuse_track.cpp b/engines/scumm/imuse_digi/dimuse_track.cpp
index b7abdd074e..28ad64670c 100644
--- a/engines/scumm/imuse_digi/dimuse_track.cpp
+++ b/engines/scumm/imuse_digi/dimuse_track.cpp
@@ -352,9 +352,9 @@ Track *IMuseDigital::cloneToFadeOutTrack(Track *track, int fadeDelay) {
 	// leaving bug number for now #1635361
 	ImuseDigiSndMgr::SoundDesc *soundDesc = _sound->cloneSound(track->soundDesc);
 	if (!soundDesc) {
 		// it fail load open old song after switch to diffrent CDs
 		// so gave up
-		error("Game not supported while playing on 2 diffrent CDs");
+		error("Game not supported while playing on 2 different CDs");
 	}
 	track->soundDesc = soundDesc;
 
@@ -352,9 +352,9 @@ Track *IMuseDigital::cloneToFadeOutTrack(Track *track, int fadeDelay) {
 	ImuseDigiSndMgr::SoundDesc *soundDesc = _sound->cloneSound(track->soundDesc);
 	if (!soundDesc) {
-		// it fail load open old song after switch to diffrent CDs
+		// it fail load open old song after switch to different CDs
 		// so gave up
-- 
cgit v1.2.3